import { useEffect, useState } from 'react';
import { CaptureProtection } from './modules';
import { CaptureEventType } from './type';
const useCaptureDetection = () => {
  const [status, setStatus] = useState(CaptureEventType.NONE);
  const [protectionStatus, setProtectionStatus] = useState({
    screenshot: false,
    record: false,
    appSwitcher: false
  });
  useEffect(() => {
    const listener = CaptureProtection.addListener(eventType => {
      if (eventType < CaptureEventType.ALLOW) {
        setStatus(eventType);
      } else if (eventType === CaptureEventType.ALLOW) {
        setProtectionStatus(_ => ({
          screenshot: false,
          record: false,
          appSwitcher: false
        }));
      } else if (eventType > CaptureEventType.ALLOW) {
        setProtectionStatus(prev => ({
          ...prev,
          screenshot: !!(eventType & CaptureEventType.PREVENT_SCREEN_CAPTURE),
          record: !!(eventType & CaptureEventType.PREVENT_SCREEN_RECORDING),
          appSwitcher: !!(eventType & CaptureEventType.PREVENT_SCREEN_APP_SWITCHING)
        }));
      }
    });
    return () => {
      var _listener$remove;
      listener === null || listener === void 0 || (_listener$remove = listener.remove) === null || _listener$remove === void 0 || _listener$remove.call(listener);
    };
  }, []);
  return {
    status,
    protectionStatus
  };
};
export { useCaptureDetection };
//# sourceMappingURL=hooks.js.map