import { Image, NativeEventEmitter, NativeModules, Platform } from 'react-native';
import { ContentMode } from './type';
const CaptureProtectionModule = (NativeModules === null || NativeModules === void 0 ? void 0 : NativeModules.CaptureProtection) ?? {};
const CaptureProtectionAndroidModule = CaptureProtectionModule;
const CaptureProtectionIOSModule = CaptureProtectionModule;
const isPlatformSupported = Platform.OS === 'ios' || Platform.OS === 'android';
const CaptureNotificationEmitter = isPlatformSupported ? new NativeEventEmitter(CaptureProtectionModule) : undefined;
const CaptureProtectionEventType = 'CaptureProtectionListener';
const allow = async option => {
  if (Platform.OS === 'android') {
    var _CaptureProtectionAnd;
    return await (CaptureProtectionAndroidModule === null || CaptureProtectionAndroidModule === void 0 || (_CaptureProtectionAnd = CaptureProtectionAndroidModule.allow) === null || _CaptureProtectionAnd === void 0 ? void 0 : _CaptureProtectionAnd.call(CaptureProtectionAndroidModule));
  }
  if (Platform.OS === 'ios') {
    const {
      record = false,
      appSwitcher = false,
      screenshot = false
    } = option ?? {
      record: true,
      appSwitcher: true,
      screenshot: true
    };
    if (screenshot) {
      var _CaptureProtectionIOS;
      await (CaptureProtectionIOSModule === null || CaptureProtectionIOSModule === void 0 || (_CaptureProtectionIOS = CaptureProtectionIOSModule.allowScreenshot) === null || _CaptureProtectionIOS === void 0 ? void 0 : _CaptureProtectionIOS.call(CaptureProtectionIOSModule));
    }
    if (appSwitcher) {
      var _CaptureProtectionIOS2;
      await (CaptureProtectionIOSModule === null || CaptureProtectionIOSModule === void 0 || (_CaptureProtectionIOS2 = CaptureProtectionIOSModule.allowAppSwitcher) === null || _CaptureProtectionIOS2 === void 0 ? void 0 : _CaptureProtectionIOS2.call(CaptureProtectionIOSModule));
    }
    if (record) {
      var _CaptureProtectionIOS3;
      await (CaptureProtectionIOSModule === null || CaptureProtectionIOSModule === void 0 || (_CaptureProtectionIOS3 = CaptureProtectionIOSModule.allowScreenRecord) === null || _CaptureProtectionIOS3 === void 0 ? void 0 : _CaptureProtectionIOS3.call(CaptureProtectionIOSModule));
    }
  }
};
const prevent = async option => {
  if (Platform.OS === 'android') {
    var _CaptureProtectionAnd2;
    return await (CaptureProtectionAndroidModule === null || CaptureProtectionAndroidModule === void 0 || (_CaptureProtectionAnd2 = CaptureProtectionAndroidModule.prevent) === null || _CaptureProtectionAnd2 === void 0 ? void 0 : _CaptureProtectionAnd2.call(CaptureProtectionAndroidModule));
  }
  if (Platform.OS === 'ios') {
    const {
      record = false,
      appSwitcher = false,
      screenshot = false
    } = option ?? {
      record: true,
      appSwitcher: true,
      screenshot: true
    };
    if (screenshot) {
      var _CaptureProtectionIOS4;
      await (CaptureProtectionIOSModule === null || CaptureProtectionIOSModule === void 0 || (_CaptureProtectionIOS4 = CaptureProtectionIOSModule.preventScreenshot) === null || _CaptureProtectionIOS4 === void 0 ? void 0 : _CaptureProtectionIOS4.call(CaptureProtectionIOSModule));
    }
    if (appSwitcher) {
      if (typeof appSwitcher === 'boolean') {
        var _CaptureProtectionIOS5;
        await (CaptureProtectionIOSModule === null || CaptureProtectionIOSModule === void 0 || (_CaptureProtectionIOS5 = CaptureProtectionIOSModule.preventAppSwitcher) === null || _CaptureProtectionIOS5 === void 0 ? void 0 : _CaptureProtectionIOS5.call(CaptureProtectionIOSModule));
      } else if (typeof appSwitcher === 'object') {
        if ('image' in appSwitcher) {
          var _CaptureProtectionIOS6;
          await (CaptureProtectionIOSModule === null || CaptureProtectionIOSModule === void 0 || (_CaptureProtectionIOS6 = CaptureProtectionIOSModule.preventAppSwitcherWithImage) === null || _CaptureProtectionIOS6 === void 0 ? void 0 : _CaptureProtectionIOS6.call(CaptureProtectionIOSModule, Image.resolveAssetSource(appSwitcher.image), (appSwitcher === null || appSwitcher === void 0 ? void 0 : appSwitcher.backgroundColor) ?? "#ffffff", (appSwitcher === null || appSwitcher === void 0 ? void 0 : appSwitcher.contentMode) ?? ContentMode.scaleAspectFit));
        } else {
          var _CaptureProtectionIOS7;
          await (CaptureProtectionIOSModule === null || CaptureProtectionIOSModule === void 0 || (_CaptureProtectionIOS7 = CaptureProtectionIOSModule.preventAppSwitcherWithText) === null || _CaptureProtectionIOS7 === void 0 ? void 0 : _CaptureProtectionIOS7.call(CaptureProtectionIOSModule, appSwitcher.text, appSwitcher === null || appSwitcher === void 0 ? void 0 : appSwitcher.textColor, appSwitcher === null || appSwitcher === void 0 ? void 0 : appSwitcher.backgroundColor));
        }
      }
    }
    if (record) {
      if (typeof record === 'boolean') {
        var _CaptureProtectionIOS8;
        await (CaptureProtectionIOSModule === null || CaptureProtectionIOSModule === void 0 || (_CaptureProtectionIOS8 = CaptureProtectionIOSModule.preventScreenRecord) === null || _CaptureProtectionIOS8 === void 0 ? void 0 : _CaptureProtectionIOS8.call(CaptureProtectionIOSModule));
      } else if (typeof record === 'object') {
        if ('image' in record) {
          var _CaptureProtectionIOS9;
          await (CaptureProtectionIOSModule === null || CaptureProtectionIOSModule === void 0 || (_CaptureProtectionIOS9 = CaptureProtectionIOSModule.preventScreenRecordWithImage) === null || _CaptureProtectionIOS9 === void 0 ? void 0 : _CaptureProtectionIOS9.call(CaptureProtectionIOSModule, Image.resolveAssetSource(record.image), (record === null || record === void 0 ? void 0 : record.backgroundColor) ?? "#ffffff", (record === null || record === void 0 ? void 0 : record.contentMode) ?? ContentMode.scaleAspectFit));
        } else {
          var _CaptureProtectionIOS0;
          await (CaptureProtectionIOSModule === null || CaptureProtectionIOSModule === void 0 || (_CaptureProtectionIOS0 = CaptureProtectionIOSModule.preventScreenRecordWithText) === null || _CaptureProtectionIOS0 === void 0 ? void 0 : _CaptureProtectionIOS0.call(CaptureProtectionIOSModule, record.text, record === null || record === void 0 ? void 0 : record.textColor, record === null || record === void 0 ? void 0 : record.backgroundColor));
        }
      }
    }
  }
};
const protectionStatus = async () => {
  if (Platform.OS === 'android') {
    var _CaptureProtectionAnd3;
    const status = await (CaptureProtectionAndroidModule === null || CaptureProtectionAndroidModule === void 0 || (_CaptureProtectionAnd3 = CaptureProtectionAndroidModule.protectionStatus) === null || _CaptureProtectionAnd3 === void 0 ? void 0 : _CaptureProtectionAnd3.call(CaptureProtectionAndroidModule));
    return {
      record: status,
      appSwitcher: status,
      screenshot: status
    };
  }
  if (Platform.OS === 'ios') {
    var _CaptureProtectionIOS1;
    return await (CaptureProtectionIOSModule === null || CaptureProtectionIOSModule === void 0 || (_CaptureProtectionIOS1 = CaptureProtectionIOSModule.protectionStatus) === null || _CaptureProtectionIOS1 === void 0 ? void 0 : _CaptureProtectionIOS1.call(CaptureProtectionIOSModule));
  }
  return {
    record: undefined,
    appSwitcher: undefined,
    screenshot: undefined
  };
};
const hasListener = async () => {
  if (Platform.OS === 'android') {
    var _CaptureProtectionAnd4;
    return await (CaptureProtectionAndroidModule === null || CaptureProtectionAndroidModule === void 0 || (_CaptureProtectionAnd4 = CaptureProtectionAndroidModule.hasListener) === null || _CaptureProtectionAnd4 === void 0 ? void 0 : _CaptureProtectionAnd4.call(CaptureProtectionAndroidModule));
  }
  if (Platform.OS === 'ios') {
    var _CaptureProtectionIOS10;
    return await (CaptureProtectionIOSModule === null || CaptureProtectionIOSModule === void 0 || (_CaptureProtectionIOS10 = CaptureProtectionIOSModule.hasListener) === null || _CaptureProtectionIOS10 === void 0 ? void 0 : _CaptureProtectionIOS10.call(CaptureProtectionIOSModule));
  }
  return undefined;
};
const addListener = callback => {
  var _CaptureNotificationE;
  if (!isPlatformSupported) {
    return;
  }
  return CaptureNotificationEmitter === null || CaptureNotificationEmitter === void 0 || (_CaptureNotificationE = CaptureNotificationEmitter.addListener) === null || _CaptureNotificationE === void 0 ? void 0 : _CaptureNotificationE.call(CaptureNotificationEmitter, CaptureProtectionEventType, callback);
};
const removeListener = async emitter => {
  if (!isPlatformSupported) {
    return;
  }
  if (emitter) {
    emitter.remove();
  }
};
const isScreenRecording = async () => {
  if (Platform.OS === 'android') {
    var _CaptureProtectionAnd5;
    return await (CaptureProtectionAndroidModule === null || CaptureProtectionAndroidModule === void 0 || (_CaptureProtectionAnd5 = CaptureProtectionAndroidModule.isScreenRecording) === null || _CaptureProtectionAnd5 === void 0 ? void 0 : _CaptureProtectionAnd5.call(CaptureProtectionAndroidModule));
  }
  if (Platform.OS === 'ios') {
    var _CaptureProtectionIOS11;
    return await (CaptureProtectionIOSModule === null || CaptureProtectionIOSModule === void 0 || (_CaptureProtectionIOS11 = CaptureProtectionIOSModule.isScreenRecording) === null || _CaptureProtectionIOS11 === void 0 ? void 0 : _CaptureProtectionIOS11.call(CaptureProtectionIOSModule));
  }
  return undefined;
};
const requestPermission = async () => {
  if (Platform.OS !== 'android') {
    console.warn('[react-native-capture-protection] requestPermission is only available on Android');
    return false;
  }
  try {
    var _CaptureProtectionAnd6;
    return await (CaptureProtectionAndroidModule === null || CaptureProtectionAndroidModule === void 0 || (_CaptureProtectionAnd6 = CaptureProtectionAndroidModule.requestPermission) === null || _CaptureProtectionAnd6 === void 0 ? void 0 : _CaptureProtectionAnd6.call(CaptureProtectionAndroidModule));
  } catch (e) {
    console.error('[react-native-capture-protection] requestPermission throw error', e);
    return false;
  }
};
export const CaptureProtection = {
  addListener,
  hasListener,
  isScreenRecording,
  requestPermission,
  allow,
  prevent,
  removeListener,
  protectionStatus
};
//# sourceMappingURL=modules.js.map